==> jc-1.4.0.tar.gz: java/lang/IllegalStateException.h <==
// public class java.lang.IllegalStateException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class b7e704701c278e65 java_lang_IllegalStateException
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_RuntimeException

#include "java/lang/RuntimeException.h"

#ifndef _JC_java_lang_IllegalStateException_H_
#define _JC_java_lang_IllegalStateException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_lang_IllegalStateException$sub_refs	_jc_java_lang_IllegalStateException$sub_refs;
typedef struct _jc_java_lang_IllegalStateException$sub_nonrefs	_jc_java_lang_IllegalStateException$sub_nonrefs;
typedef struct _jc_java_lang_IllegalStateException$refs	_jc_java_lang_IllegalStateException$refs;
typedef struct _jc_java_lang_IllegalStateException$nonrefs	_jc_java_lang_IllegalStateException$nonrefs;
typedef struct _jc_java_lang_IllegalStateException$object	_jc_java_lang_IllegalStateException$object;

typedef struct _jc_java_lang_IllegalStateException$fields_struct	_jc_java_lang_IllegalStateException$fields_struct;
typedef const struct _jc_java_lang_IllegalStateException$vmethods	_jc_java_lang_IllegalStateException$vmethods;
typedef const struct _jc_java_lang_IllegalStateException$vtable	_jc_java_lang_IllegalStateException$vtable;
typedef const struct _jc_java_lang_IllegalStateException$vtype	_jc_java_lang_IllegalStateException$vtype;

// Class fields structure
struct _jc_java_lang_IllegalStateException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_lang_IllegalStateException$fields_struct _jc_java_lang_IllegalStateException$class_fields;

// Constructors
extern void _jc_java_lang_IllegalStateException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_IllegalStateException$object *);
extern void _jc_java_lang_IllegalStateException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_lang_IllegalStateException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_java_lang_IllegalStateException$vmethods {
};

// Vtable
struct _jc_java_lang_IllegalStateException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_java_lang_IllegalStateException$vmethods	java_lang_IllegalStateException;
};

// Vtype
struct _jc_java_lang_IllegalStateException$vtype {
	_jc_type			type;
	_jc_java_lang_IllegalStateException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_IllegalStateException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_IllegalStateException$refs {
    _jc_java_lang_IllegalStateException$sub_refs	java_lang_IllegalStateException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_IllegalStateException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_IllegalStateException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_java_lang_IllegalStateException$sub_nonrefs	java_lang_IllegalStateException;
};

// Object instance structure
struct _jc_java_lang_IllegalStateException$object {
	_jc_java_lang_IllegalStateException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_IllegalStateException$vtype	*vtype;
	_jc_java_lang_IllegalStateException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_IllegalStateException$vtype _jc_java_lang_IllegalStateException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_IllegalStateException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_IllegalStateException$class_object;

#endif	/* _JC_java_lang_IllegalStateException_H_ */

==> jc-1.4.6.tar.gz: java/lang/IllegalStateException.h <==
// public class java.lang.IllegalStateException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class b7e704701c278e65 java_lang_IllegalStateException
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_RuntimeException

#include "java/lang/RuntimeException.h"

#ifndef _JC_java_lang_IllegalStateException_H_
#define _JC_java_lang_IllegalStateException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_lang_IllegalStateException$sub_refs	_jc_java_lang_IllegalStateException$sub_refs;
typedef struct _jc_java_lang_IllegalStateException$sub_nonrefs	_jc_java_lang_IllegalStateException$sub_nonrefs;
typedef struct _jc_java_lang_IllegalStateException$refs	_jc_java_lang_IllegalStateException$refs;
typedef struct _jc_java_lang_IllegalStateException$nonrefs	_jc_java_lang_IllegalStateException$nonrefs;
typedef struct _jc_java_lang_IllegalStateException$object	_jc_java_lang_IllegalStateException$object;

typedef struct _jc_java_lang_IllegalStateException$fields_struct	_jc_java_lang_IllegalStateException$fields_struct;
typedef const struct _jc_java_lang_IllegalStateException$vmethods	_jc_java_lang_IllegalStateException$vmethods;
typedef const struct _jc_java_lang_IllegalStateException$vtable	_jc_java_lang_IllegalStateException$vtable;
typedef const struct _jc_java_lang_IllegalStateException$vtype	_jc_java_lang_IllegalStateException$vtype;

// Class fields structure
struct _jc_java_lang_IllegalStateException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_lang_IllegalStateException$fields_struct _jc_java_lang_IllegalStateException$class_fields;

// Constructors
extern void _jc_java_lang_IllegalStateException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_IllegalStateException$object *) _JC_JCNI_ATTR;
extern void _jc_java_lang_IllegalStateException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_lang_IllegalStateException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_lang_IllegalStateException$vmethods {
};

// Vtable
struct _jc_java_lang_IllegalStateException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_java_lang_IllegalStateException$vmethods	java_lang_IllegalStateException;
};

// Vtype
struct _jc_java_lang_IllegalStateException$vtype {
	_jc_type			type;
	_jc_java_lang_IllegalStateException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_IllegalStateException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_IllegalStateException$refs {
    _jc_java_lang_IllegalStateException$sub_refs	java_lang_IllegalStateException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_IllegalStateException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_IllegalStateException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_java_lang_IllegalStateException$sub_nonrefs	java_lang_IllegalStateException;
};

// Object instance structure
struct _jc_java_lang_IllegalStateException$object {
	_jc_java_lang_IllegalStateException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_IllegalStateException$vtype	*vtype;
	_jc_java_lang_IllegalStateException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_IllegalStateException$vtype _jc_java_lang_IllegalStateException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_IllegalStateException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_IllegalStateException$class_object;

#endif	/* _JC_java_lang_IllegalStateException_H_ */
